@@ -1,15 +1,12 @@
 from microconventions.sep_conventions import SepConventions
 from enum import Enum
+from microconventions.type_conventions import StrEnum
 
-
-class RatingVariety(Enum):
+class RatingVariety(StrEnum):
     """ Enumerates varieties of leaderboards """
     memory = 0
     delay = 1
 
-    def __str__(self):
-        return super().__str__().split('.')[1]
-
     def split(self):
         return self.__str__().split('_and_')
 
@@ -23,15 +20,15 @@ class RatingConventions(SepConventions):
         super().__init__(**kwargs)
         self.RATING = "rating" + self.SEP
 
-    def rating_name(self, rating_variety, **kwargs):
+    def rating_name(self, variety, **kwargs):
         """ Name for rating tables
               variety:  RatingVariety
         """
-        return self.RATING + str(rating_variety) + self.SEP + rating_variety.instance_name(**kwargs)
+        return self.RATING + str(variety) + self.SEP + variety.instance_name(**kwargs)
 
 
 if __name__=='__main__':
     sc = RatingConventions()
     for variety in RatingVariety:
         print(variety)
-        print(sc.rating_name(rating_variety=variety, name='bill', sponsor='mary', memory=10000, delay=72, host='home', genus='bivariate'))
\ No newline at end of file
+        print(sc.rating_name(variety=variety, name='bill', sponsor='mary', memory=10000, delay=72, host='home', genus='bivariate'))
\ No newline at end of file
